function _aws_cdk_aws_lambda_destinations_LambdaDestinationOptions(p) {
}
function _aws_cdk_aws_lambda_destinations_EventBridgeDestination(p) {
}
function _aws_cdk_aws_lambda_destinations_SqsDestination(p) {
}
function _aws_cdk_aws_lambda_destinations_SnsDestination(p) {
}
function _aws_cdk_aws_lambda_destinations_LambdaDestination(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_lambda_destinations_LambdaDestinationOptions, _aws_cdk_aws_lambda_destinations_EventBridgeDestination, _aws_cdk_aws_lambda_destinations_SqsDestination, _aws_cdk_aws_lambda_destinations_SnsDestination, _aws_cdk_aws_lambda_destinations_LambdaDestination };
module.exports.DeprecationError = DeprecationError;
